@@ -6,7 +6,7 @@ import time
 import avro.io
 import avro.schema
 from confluent_kafka import Producer, Consumer, KafkaError
-from confluent_kafka.admin import AdminClient, NewTopic
+from confluent_kafka.admin import AdminClient, NewTopic, NewPartitions
 
 
 class MessageException(Exception):
@@ -17,16 +17,20 @@ class MessageException(Exception):
 class EventManager:
     def __init__(self):
         self.adminClient = AdminClient({
-            "bootstrap.servers": "10.0.0.212:9092"
+            "bootstrap.servers": "127.0.0.1:9092"
         })
         self.producerClient = Producer({
-            "bootstrap.servers": "10.0.0.212:9092"
+            "bootstrap.servers": "127.0.0.1:9092"
         })
 
     def create_address(self, address: str):
         if address not in self.adminClient.list_topics().topics:
             self.adminClient.create_topics([NewTopic(address, 1, 1)])
 
+    def modify_mailbox_size(self, address: str, size: int):
+        if address in self.adminClient.list_topics().topics:
+            self.adminClient.create_partitions([NewPartitions(address, size)])
+
     def delete_address(self, address: str):
         if address not in self.adminClient.list_topics().topics:
             raise MessageException(f"Address {address} was not found")
@@ -35,7 +39,7 @@ class EventManager:
     @staticmethod
     def send_command_to_address(address: str, schema_str: str, command_object: object):
         record_schema = avro.schema.parse(schema_str)
-        conf = {'bootstrap.servers': "10.0.0.212:9092"}
+        conf = {'bootstrap.servers': "127.0.0.1:9092"}
 
         producer = Producer(**conf)
 
@@ -53,7 +57,7 @@ class EventManager:
     @staticmethod
     def wait_for_command(address: str, schema_str: str, on):
 
-        conf = {'bootstrap.servers': "10.0.0.212:9092",
+        conf = {'bootstrap.servers': "127.0.0.1:9092",
                 'group.id': 'command.query',
                 'default.topic.config': {'auto.offset.reset': 'smallest'}}
 
@@ -94,6 +98,7 @@ class EventManager:
 if __name__ == "__main__":
     em = EventManager()
     em.create_address('unit-test')
+    em.modify_mailbox_size('unit-test', 3)
     schema = """
     {
         "namespace": "confluent.io.examples.serialization.avro",
